## Immediate TODO

- [x] more job details when printing job stuff, especially when removing or killing
- [x] setup
- [x] not able to select address at setup (removed, always localhost)
- [x] nx run should crash if gpus not available
- [x] make fact that you can press enter for default more obvious
- [x] simple way to get logs with nexus-server cli
- [x] automatically load .env in dir
- [ ] dependent jobs (a after b is done)
- [ ] better secrets management
- [ ] git branch mode
- [ ] multi node and auth
- [ ] documentation
- [ ] job execution isolation
